@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Warnings::Version;
-$Warnings::Version::VERSION = '0.002003';
+$Warnings::Version::VERSION = '0.003000';
 # ABSTRACT: Load warnings from a specific version of perl
 
 use 5.006;
@@ -31,6 +31,13 @@ $warnings{ '5.20'     } = [ @{ $warnings{all} }, qw/ experimental::autoderef
     experimental::postderef experimental::regex_sets experimental::signatures
     experimental::smartmatch imprecision layer syscalls illegalproto threads
     non_unicode nonchar surrogate / ];
+$warnings{ '5.22'     } = [ @{ $warnings{all} }, qw/ experimental::autoderef
+    experimental::bitwise experimental::const_attr experimental::lexical_subs
+    experimental::lexical_topic experimental::postderef experimental::re_strict
+    experimental::refaliasing experimental::regex_sets experimental::signatures
+    experimental::smartmatch experimental::win32_perlio imprecision layer
+    syscalls locale missing redundant illegalproto threads non_unicode nonchar
+    surrogate /];
 
 
 sub import {
@@ -93,7 +100,7 @@ Warnings::Version - Load warnings from a specific version of perl
 
 =head1 VERSION
 
-version 0.002003
+version 0.003000
 
 =head1 SYNOPSIS
 
